type token =
  | CALL_OF
  | RETURN_OF
  | CALLORRETURN_OF
  | IDENTIFIER of (string)
  | METAVAR of (string)
  | INT of (string)
  | AFF
  | LCURLY
  | RCURLY
  | LPAREN
  | RPAREN
  | LSQUARE
  | RSQUARE
  | LBRACELBRACE
  | RBRACERBRACE
  | RARROW
  | TRUE
  | FALSE
  | NOT
  | DOT
  | AMP
  | COLON
  | SEMI_COLON
  | COMMA
  | PIPE
  | CARET
  | QUESTION
  | COLUMNCOLUMN
  | EQ
  | LT
  | GT
  | LE
  | GE
  | NEQ
  | PLUS
  | MINUS
  | SLASH
  | STAR
  | PERCENT
  | OR
  | AND
  | INIT
  | ACCEPT
  | DETERMINISTIC
  | OTHERWISE
  | EOF

open Parsing;;
let _ = parse_error;;
# 30 "src/plugins/aorai/yaparser.mly"
open Cil_types
open Logic_ptree
open Promelaast
open Bool3

type options = Deterministic | Init of string list | Accept of string list

let to_seq c =
  [{ condition = Some c;
     nested = [];
     min_rep = Some Data_for_aorai.cst_one;
     max_rep = Some Data_for_aorai.cst_one;
   }]

let is_no_repet (min,max) =
  let is_one c = Extlib.may_map Data_for_aorai.is_cst_one ~dft:false c in
  is_one min && is_one max

let observed_states      = Hashtbl.create 1
let prefetched_states    = Hashtbl.create 1

let fetch_and_create_state name =
  Hashtbl.remove prefetched_states name ;
  try
    Hashtbl.find observed_states name
  with
    Not_found ->
      let s = Data_for_aorai.new_state name in
      Hashtbl.add observed_states name s; s
;;

let prefetch_and_create_state name =
    if (Hashtbl.mem prefetched_states name) ||
      not (Hashtbl.mem observed_states name)
    then
      begin
        let s= fetch_and_create_state name in
        Hashtbl.add prefetched_states name name;
        s
      end
    else
      (fetch_and_create_state name)
;;

let set_init_state id =
  try
    let state = Hashtbl.find observed_states id in
    state.init <- True
  with Not_found ->
    Aorai_option.abort "no state '%s'" id

let set_accept_state id =
  try
    let state = Hashtbl.find observed_states id in
    state.acceptation <- True
  with Not_found ->
    Aorai_option.abort "no state '%s'" id

let add_metavariable map (name,typename) =
  let ty = match typename with
    | "int" -> TInt(IInt, [])
    | "char" -> TInt(IChar, [])
    | "long" -> TInt(ILong, [])
    | _ ->
      Aorai_option.abort "Unrecognized type %s for metavariable %s"
        typename name
  in
  if Datatype.String.Map.mem name map then
    Aorai_option.abort "The metavariable %s is declared twice" name;
  let vi = Cil.makeGlobalVar (Data_for_aorai.get_fresh ("aorai_" ^ name)) ty in
  Datatype.String.Map.add name vi map

let check_state st =
  if st.acceptation=Undefined || st.init=Undefined then
   Aorai_option.abort
    "Error: the state '%s' is used but never defined." st.name

let interpret_option = function
  | Init states ->
    List.iter set_init_state states
  | Accept states ->
    List.iter set_accept_state states
  | Deterministic ->
    Aorai_option.Deterministic.set true

let build_automaton options metavariables trans =
  let htable_to_list table = Hashtbl.fold (fun _ st l -> st :: l) table [] in
  let states = htable_to_list observed_states
  and undefined_states = htable_to_list prefetched_states
  and metavariables =
    List.fold_left add_metavariable Datatype.String.Map.empty metavariables
  in
  List.iter interpret_option options;
  List.iter check_state states;
  if not (List.exists (fun st -> st.init=True) states) then
    Aorai_option.abort "Automaton does not declare an initial state";
  if undefined_states <> [] then
    Aorai_option.abort "Error: the state(s) %a are used but never defined."
      (Pretty_utils.pp_list ~sep:"," Format.pp_print_string) undefined_states;
  { states; trans; metavariables }


type pre_cond = Behavior of string | Pre of Promelaast.condition


# 158 "src/plugins/aorai/yaparser.ml"
let yytransl_const = [|
  257 (* CALL_OF *);
  258 (* RETURN_OF *);
  259 (* CALLORRETURN_OF *);
  263 (* AFF *);
  264 (* LCURLY *);
  265 (* RCURLY *);
  266 (* LPAREN *);
  267 (* RPAREN *);
  268 (* LSQUARE *);
  269 (* RSQUARE *);
  270 (* LBRACELBRACE *);
  271 (* RBRACERBRACE *);
  272 (* RARROW *);
  273 (* TRUE *);
  274 (* FALSE *);
  275 (* NOT *);
  276 (* DOT *);
  277 (* AMP *);
  278 (* COLON *);
  279 (* SEMI_COLON *);
  280 (* COMMA *);
  281 (* PIPE *);
  282 (* CARET *);
  283 (* QUESTION *);
  284 (* COLUMNCOLUMN *);
  285 (* EQ *);
  286 (* LT *);
  287 (* GT *);
  288 (* LE *);
  289 (* GE *);
  290 (* NEQ *);
  291 (* PLUS *);
  292 (* MINUS *);
  293 (* SLASH *);
  294 (* STAR *);
  295 (* PERCENT *);
  296 (* OR *);
  297 (* AND *);
  298 (* INIT *);
  299 (* ACCEPT *);
  300 (* DETERMINISTIC *);
  301 (* OTHERWISE *);
    0 (* EOF *);
    0|]

let yytransl_block = [|
  260 (* IDENTIFIER *);
  261 (* METAVAR *);
  262 (* INT *);
    0|]

let yylhs = "\255\255\
\001\000\002\000\002\000\005\000\006\000\006\000\007\000\007\000\
\003\000\003\000\008\000\008\000\009\000\004\000\004\000\010\000\
\011\000\011\000\012\000\012\000\012\000\015\000\015\000\016\000\
\016\000\017\000\017\000\017\000\017\000\017\000\019\000\019\000\
\020\000\020\000\013\000\021\000\021\000\021\000\021\000\021\000\
\021\000\021\000\021\000\018\000\018\000\018\000\018\000\018\000\
\018\000\018\000\018\000\018\000\018\000\023\000\023\000\023\000\
\023\000\023\000\023\000\023\000\022\000\022\000\022\000\024\000\
\024\000\024\000\024\000\026\000\026\000\026\000\026\000\025\000\
\025\000\025\000\025\000\027\000\027\000\027\000\028\000\028\000\
\028\000\028\000\028\000\014\000\014\000\029\000\029\000\031\000\
\030\000\030\000\000\000"

let yylen = "\002\000\
\003\000\002\000\001\000\004\000\000\000\002\000\003\000\001\000\
\000\000\001\000\002\000\001\000\004\000\002\000\001\000\004\000\
\003\000\001\000\006\000\004\000\003\000\001\000\003\000\000\000\
\001\000\001\000\003\000\006\000\005\000\004\000\002\000\003\000\
\000\000\003\000\002\000\000\000\001\000\001\000\001\000\005\000\
\003\000\004\000\004\000\004\000\004\000\004\000\001\000\001\000\
\002\000\003\000\003\000\003\000\001\000\003\000\003\000\003\000\
\003\000\003\000\003\000\001\000\003\000\003\000\001\000\003\000\
\003\000\003\000\001\000\001\000\003\000\003\000\003\000\001\000\
\002\000\001\000\003\000\003\000\004\000\001\000\002\000\005\000\
\001\000\003\000\001\000\000\000\002\000\003\000\001\000\003\000\
\000\000\001\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\000\000\091\000\000\000\003\000\000\000\000\000\
\000\000\002\000\000\000\012\000\000\000\000\000\000\000\000\000\
\000\000\015\000\011\000\008\000\000\000\004\000\000\000\000\000\
\014\000\000\000\013\000\000\000\000\000\000\000\000\000\018\000\
\000\000\000\000\087\000\007\000\000\000\000\000\000\000\000\000\
\000\000\083\000\072\000\000\000\000\000\047\000\048\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\053\000\000\000\
\068\000\000\000\000\000\078\000\000\000\016\000\000\000\000\000\
\000\000\085\000\000\000\000\000\088\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\049\000\073\000\000\000\000\000\000\000\000\000\039\000\
\037\000\038\000\035\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\017\000\021\000\
\086\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\031\000\000\000\052\000\075\000\082\000\000\000\027\000\
\000\000\000\000\000\000\000\000\000\000\000\000\054\000\055\000\
\056\000\057\000\058\000\059\000\061\000\062\000\064\000\065\000\
\066\000\069\000\070\000\071\000\000\000\076\000\020\000\000\000\
\045\000\046\000\044\000\000\000\000\000\030\000\000\000\032\000\
\025\000\000\000\023\000\000\000\000\000\041\000\000\000\077\000\
\000\000\080\000\029\000\000\000\019\000\043\000\042\000\000\000\
\034\000\028\000\040\000"

let yydgoto = "\002\000\
\004\000\005\000\009\000\017\000\006\000\014\000\021\000\011\000\
\012\000\018\000\031\000\032\000\080\000\033\000\161\000\162\000\
\052\000\053\000\076\000\158\000\091\000\054\000\055\000\056\000\
\057\000\058\000\059\000\060\000\034\000\066\000\035\000"

let yysindex = "\032\000\
\218\254\000\000\022\255\000\000\010\255\000\000\026\255\029\255\
\070\255\000\000\080\255\000\000\091\255\077\255\117\255\105\255\
\070\255\000\000\000\000\000\000\119\255\000\000\108\255\254\254\
\000\000\142\255\000\000\148\255\018\255\158\255\073\255\000\000\
\151\255\141\255\000\000\000\000\114\255\163\255\183\255\188\255\
\112\255\000\000\000\000\087\255\018\255\000\000\000\000\087\255\
\193\255\076\255\192\255\107\255\156\255\013\000\000\000\041\000\
\000\000\123\255\090\255\000\000\191\255\000\000\254\254\221\255\
\158\255\000\000\220\255\114\255\000\000\223\255\227\255\228\255\
\065\255\087\255\229\255\225\255\255\254\013\000\090\255\200\255\
\244\255\000\000\000\000\076\255\090\255\158\255\008\255\000\000\
\000\000\000\000\000\000\087\255\087\255\114\255\114\255\114\255\
\114\255\114\255\114\255\114\255\114\255\114\255\114\255\114\255\
\114\255\114\255\114\255\114\255\237\255\002\000\000\000\000\000\
\000\000\253\255\255\255\004\000\024\000\026\000\097\255\028\000\
\001\255\000\000\018\255\000\000\000\000\000\000\018\255\000\000\
\067\255\034\000\114\255\249\254\156\255\156\255\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\038\000\000\000\000\000\249\255\
\000\000\000\000\000\000\087\255\049\000\000\000\055\000\000\000\
\000\000\060\000\000\000\069\000\072\000\000\000\103\255\000\000\
\032\255\000\000\000\000\055\000\000\000\000\000\000\000\075\000\
\000\000\000\000\000\000"

let yyrindex = "\000\000\
\000\000\000\000\000\000\000\000\081\000\000\000\064\000\000\000\
\000\000\000\000\090\000\000\000\000\000\000\000\000\000\000\000\
\095\001\000\000\000\000\000\000\073\000\000\000\000\000\082\000\
\000\000\000\000\000\000\000\000\000\000\082\000\000\000\000\000\
\000\000\087\000\000\000\000\000\000\000\000\000\000\000\000\000\
\247\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\252\255\124\255\093\000\000\000\059\000\
\000\000\025\000\179\255\000\000\000\000\000\000\082\000\000\000\
\089\000\000\000\145\255\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\088\255\111\000\125\255\
\000\000\000\000\000\000\000\000\213\255\082\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\177\000\000\000\
\000\000\000\000\086\000\000\000\000\000\000\000\178\255\000\000\
\000\000\000\000\000\000\000\000\145\000\154\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\177\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\177\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000"

let yygindex = "\000\000\
\000\000\000\000\000\000\000\000\102\001\000\000\000\000\000\000\
\106\001\101\001\000\000\056\001\092\001\235\255\238\255\252\000\
\000\000\216\255\000\000\122\255\000\000\219\255\000\000\000\000\
\007\001\000\000\217\255\000\000\000\000\000\000\059\001"

let yytablesize = 471
let yytable = "\069\000\
\003\000\166\000\028\000\077\000\079\000\029\000\078\000\082\000\
\061\000\124\000\085\000\067\000\042\000\043\000\008\000\160\000\
\167\000\068\000\038\000\039\000\040\000\041\000\042\000\043\000\
\171\000\007\000\081\000\044\000\079\000\045\000\115\000\131\000\
\001\000\121\000\046\000\047\000\048\000\178\000\092\000\093\000\
\092\000\093\000\030\000\049\000\129\000\050\000\177\000\013\000\
\003\000\132\000\015\000\133\000\134\000\049\000\120\000\050\000\
\135\000\136\000\137\000\138\000\139\000\140\000\141\000\142\000\
\130\000\038\000\039\000\040\000\041\000\042\000\043\000\092\000\
\093\000\016\000\044\000\119\000\045\000\126\000\108\000\067\000\
\042\000\046\000\047\000\048\000\008\000\084\000\109\000\038\000\
\039\000\040\000\067\000\042\000\043\000\165\000\020\000\062\000\
\044\000\063\000\060\000\022\000\049\000\108\000\050\000\046\000\
\047\000\048\000\067\000\042\000\043\000\109\000\156\000\175\000\
\068\000\050\000\087\000\169\000\157\000\067\000\042\000\043\000\
\023\000\073\000\049\000\068\000\050\000\074\000\024\000\060\000\
\060\000\176\000\027\000\026\000\026\000\088\000\026\000\022\000\
\026\000\022\000\049\000\075\000\050\000\089\000\026\000\105\000\
\090\000\036\000\026\000\106\000\107\000\049\000\026\000\050\000\
\081\000\081\000\037\000\081\000\081\000\081\000\026\000\081\000\
\081\000\026\000\028\000\065\000\081\000\081\000\064\000\081\000\
\081\000\081\000\081\000\081\000\070\000\081\000\081\000\081\000\
\081\000\081\000\081\000\081\000\081\000\081\000\081\000\081\000\
\081\000\081\000\074\000\074\000\024\000\074\000\024\000\074\000\
\071\000\074\000\074\000\092\000\093\000\072\000\083\000\074\000\
\086\000\074\000\074\000\074\000\074\000\074\000\110\000\074\000\
\074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
\074\000\074\000\074\000\074\000\079\000\079\000\127\000\079\000\
\112\000\079\000\116\000\079\000\079\000\114\000\117\000\118\000\
\122\000\079\000\123\000\079\000\079\000\079\000\079\000\079\000\
\150\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
\079\000\079\000\079\000\079\000\079\000\079\000\081\000\081\000\
\128\000\081\000\081\000\081\000\036\000\151\000\036\000\152\000\
\036\000\125\000\081\000\081\000\157\000\081\000\153\000\081\000\
\081\000\081\000\036\000\081\000\081\000\081\000\081\000\081\000\
\081\000\081\000\081\000\081\000\081\000\081\000\081\000\081\000\
\067\000\067\000\154\000\067\000\155\000\067\000\159\000\067\000\
\067\000\094\000\095\000\096\000\097\000\098\000\099\000\067\000\
\067\000\164\000\168\000\067\000\170\000\067\000\067\000\067\000\
\067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
\067\000\067\000\063\000\063\000\156\000\063\000\172\000\063\000\
\173\000\063\000\063\000\100\000\101\000\102\000\103\000\104\000\
\174\000\063\000\063\000\179\000\009\000\063\000\005\000\063\000\
\063\000\063\000\063\000\063\000\063\000\010\000\001\000\006\000\
\024\000\084\000\063\000\063\000\060\000\060\000\089\000\060\000\
\090\000\060\000\010\000\060\000\143\000\144\000\145\000\146\000\
\147\000\148\000\149\000\060\000\019\000\025\000\111\000\060\000\
\051\000\074\000\163\000\113\000\000\000\000\000\000\000\060\000\
\000\000\000\000\060\000\074\000\060\000\060\000\000\000\074\000\
\074\000\000\000\000\000\074\000\074\000\074\000\074\000\074\000\
\074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
\051\000\051\000\000\000\051\000\000\000\051\000\000\000\051\000\
\000\000\050\000\050\000\000\000\050\000\000\000\050\000\051\000\
\050\000\000\000\000\000\051\000\000\000\000\000\000\000\000\000\
\050\000\000\000\000\000\051\000\050\000\000\000\051\000\000\000\
\033\000\033\000\000\000\033\000\050\000\033\000\000\000\050\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\033\000\
\000\000\000\000\000\000\033\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\033\000\000\000\000\000\033\000"

let yycheck = "\037\000\
\039\001\009\001\005\001\044\000\044\000\008\001\044\000\048\000\
\030\000\011\001\050\000\004\001\005\001\006\001\005\001\015\001\
\024\001\010\001\001\001\002\001\003\001\004\001\005\001\006\001\
\159\000\004\001\045\000\010\001\068\000\012\001\068\000\024\001\
\001\000\074\000\017\001\018\001\019\001\172\000\040\001\041\001\
\040\001\041\001\045\001\036\001\084\000\038\001\015\001\022\001\
\039\001\087\000\022\001\092\000\093\000\036\001\073\000\038\001\
\094\000\095\000\096\000\097\000\098\000\099\000\100\000\101\000\
\086\000\001\001\002\001\003\001\004\001\005\001\006\001\040\001\
\041\001\004\001\010\001\011\001\012\001\011\001\012\001\004\001\
\005\001\017\001\018\001\019\001\005\001\010\001\020\001\001\001\
\002\001\003\001\004\001\005\001\006\001\131\000\004\001\023\001\
\010\001\025\001\011\001\023\001\036\001\012\001\038\001\017\001\
\018\001\019\001\004\001\005\001\006\001\020\001\014\001\009\001\
\010\001\038\001\008\001\156\000\020\001\004\001\005\001\006\001\
\004\001\010\001\036\001\010\001\038\001\014\001\022\001\040\001\
\041\001\167\000\023\001\008\001\009\001\027\001\011\001\011\001\
\013\001\013\001\036\001\028\001\038\001\035\001\024\001\021\001\
\038\001\004\001\023\001\025\001\026\001\036\001\027\001\038\001\
\008\001\009\001\007\001\011\001\012\001\013\001\035\001\015\001\
\016\001\038\001\005\001\023\001\020\001\021\001\016\001\023\001\
\024\001\025\001\026\001\027\001\010\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\038\001\039\001\
\040\001\041\001\008\001\009\001\011\001\011\001\013\001\013\001\
\010\001\015\001\016\001\040\001\041\001\010\001\006\001\021\001\
\009\001\023\001\024\001\025\001\026\001\027\001\016\001\029\001\
\030\001\031\001\032\001\033\001\034\001\035\001\036\001\037\001\
\038\001\039\001\040\001\041\001\008\001\009\001\023\001\011\001\
\004\001\013\001\004\001\015\001\016\001\010\001\004\001\004\001\
\004\001\021\001\010\001\023\001\024\001\025\001\026\001\027\001\
\004\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\040\001\041\001\008\001\009\001\
\013\001\011\001\012\001\013\001\009\001\004\001\011\001\011\001\
\013\001\011\001\020\001\021\001\020\001\023\001\011\001\025\001\
\026\001\027\001\023\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\039\001\040\001\041\001\
\008\001\009\001\011\001\011\001\011\001\013\001\011\001\015\001\
\016\001\029\001\030\001\031\001\032\001\033\001\034\001\023\001\
\024\001\016\001\013\001\027\001\004\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\038\001\039\001\
\040\001\041\001\008\001\009\001\014\001\011\001\011\001\013\001\
\004\001\015\001\016\001\035\001\036\001\037\001\038\001\039\001\
\009\001\023\001\024\001\009\001\004\001\027\001\023\001\029\001\
\030\001\031\001\032\001\033\001\034\001\004\001\000\000\023\001\
\011\001\016\001\040\001\041\001\008\001\009\001\016\001\011\001\
\016\001\013\001\005\000\015\001\102\000\103\000\104\000\105\000\
\106\000\107\000\108\000\023\001\011\000\017\000\063\000\027\001\
\029\000\011\001\127\000\065\000\255\255\255\255\255\255\035\001\
\255\255\255\255\038\001\021\001\040\001\041\001\255\255\025\001\
\026\001\255\255\255\255\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\039\001\040\001\041\001\
\008\001\009\001\255\255\011\001\255\255\013\001\255\255\015\001\
\255\255\008\001\009\001\255\255\011\001\255\255\013\001\023\001\
\015\001\255\255\255\255\027\001\255\255\255\255\255\255\255\255\
\023\001\255\255\255\255\035\001\027\001\255\255\038\001\255\255\
\008\001\009\001\255\255\011\001\035\001\013\001\255\255\038\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\023\001\
\255\255\255\255\255\255\027\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\035\001\255\255\255\255\038\001"

let yynames_const = "\
  CALL_OF\000\
  RETURN_OF\000\
  CALLORRETURN_OF\000\
  AFF\000\
  LCURLY\000\
  RCURLY\000\
  LPAREN\000\
  RPAREN\000\
  LSQUARE\000\
  RSQUARE\000\
  LBRACELBRACE\000\
  RBRACERBRACE\000\
  RARROW\000\
  TRUE\000\
  FALSE\000\
  NOT\000\
  DOT\000\
  AMP\000\
  COLON\000\
  SEMI_COLON\000\
  COMMA\000\
  PIPE\000\
  CARET\000\
  QUESTION\000\
  COLUMNCOLUMN\000\
  EQ\000\
  LT\000\
  GT\000\
  LE\000\
  GE\000\
  NEQ\000\
  PLUS\000\
  MINUS\000\
  SLASH\000\
  STAR\000\
  PERCENT\000\
  OR\000\
  AND\000\
  INIT\000\
  ACCEPT\000\
  DETERMINISTIC\000\
  OTHERWISE\000\
  EOF\000\
  "

let yynames_block = "\
  IDENTIFIER\000\
  METAVAR\000\
  INT\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'options) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'metavars) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'states) in
    Obj.repr(
# 168 "src/plugins/aorai/yaparser.mly"
                               ( build_automaton _1 _2 _3 )
# 510 "src/plugins/aorai/yaparser.ml"
               : Promelaast.parsed_automaton))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'options) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'option) in
    Obj.repr(
# 171 "src/plugins/aorai/yaparser.mly"
                   ( _1 @ [_2] )
# 518 "src/plugins/aorai/yaparser.ml"
               : 'options))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'option) in
    Obj.repr(
# 172 "src/plugins/aorai/yaparser.mly"
                   ( [_1] )
# 525 "src/plugins/aorai/yaparser.ml"
               : 'options))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'opt_identifiers) in
    Obj.repr(
# 176 "src/plugins/aorai/yaparser.mly"
                                                  ( 
    match _2 with
    | "init" -> Init _3
    | "accept" -> Accept _3
    | "deterministic" -> Deterministic
    | _ ->  Aorai_option.abort "unknown option: '%s'" _2
  )
# 539 "src/plugins/aorai/yaparser.ml"
               : 'option))
; (fun __caml_parser_env ->
    Obj.repr(
# 185 "src/plugins/aorai/yaparser.mly"
                ( [] )
# 545 "src/plugins/aorai/yaparser.ml"
               : 'opt_identifiers))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_list) in
    Obj.repr(
# 186 "src/plugins/aorai/yaparser.mly"
                  ( _2 )
# 552 "src/plugins/aorai/yaparser.ml"
               : 'opt_identifiers))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'id_list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 190 "src/plugins/aorai/yaparser.mly"
                             ( _1 @ [_3] )
# 560 "src/plugins/aorai/yaparser.ml"
               : 'id_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 191 "src/plugins/aorai/yaparser.mly"
                             ( [_1] )
# 567 "src/plugins/aorai/yaparser.ml"
               : 'id_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 195 "src/plugins/aorai/yaparser.mly"
                       ( [] )
# 573 "src/plugins/aorai/yaparser.ml"
               : 'metavars))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'non_empty_metavars) in
    Obj.repr(
# 196 "src/plugins/aorai/yaparser.mly"
                       ( _1 )
# 580 "src/plugins/aorai/yaparser.ml"
               : 'metavars))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'non_empty_metavars) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'metavar) in
    Obj.repr(
# 199 "src/plugins/aorai/yaparser.mly"
                               ( _1 @ [_2] )
# 588 "src/plugins/aorai/yaparser.ml"
               : 'non_empty_metavars))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'metavar) in
    Obj.repr(
# 200 "src/plugins/aorai/yaparser.mly"
                               ( [_1] )
# 595 "src/plugins/aorai/yaparser.ml"
               : 'non_empty_metavars))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 204 "src/plugins/aorai/yaparser.mly"
                                        ( _1,_3 )
# 603 "src/plugins/aorai/yaparser.ml"
               : 'metavar))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'states) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'state) in
    Obj.repr(
# 208 "src/plugins/aorai/yaparser.mly"
                 ( _1@_2 )
# 611 "src/plugins/aorai/yaparser.ml"
               : 'states))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'state) in
    Obj.repr(
# 209 "src/plugins/aorai/yaparser.mly"
          ( _1 )
# 618 "src/plugins/aorai/yaparser.ml"
               : 'states))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'transitions) in
    Obj.repr(
# 213 "src/plugins/aorai/yaparser.mly"
                                            (
      let start_state = fetch_and_create_state _1 in
      let (_, transitions) =
        List.fold_left
          (fun (otherwise, transitions) (cross,actions,stop_state) ->
            if otherwise then
              Aorai_option.abort
                "'other' directive in definition of %s \
                transitions is not the last one" start_state.name
            else begin
              let trans =
                { start=start_state; stop=stop_state;
                  cross; actions; numt=(-1) }::transitions
              in
              let otherwise =
                match cross with
                  | Otherwise -> true
                  | Seq _ -> false
              in otherwise, trans
            end)
          (false,[]) _3
      in
      List.rev transitions
  )
# 649 "src/plugins/aorai/yaparser.ml"
               : 'state))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'transitions) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'transition) in
    Obj.repr(
# 239 "src/plugins/aorai/yaparser.mly"
                                ( _1@[_3] )
# 657 "src/plugins/aorai/yaparser.ml"
               : 'transitions))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'transition) in
    Obj.repr(
# 240 "src/plugins/aorai/yaparser.mly"
               ( [_1] )
# 664 "src/plugins/aorai/yaparser.ml"
               : 'transitions))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'seq_elt) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'actions) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 246 "src/plugins/aorai/yaparser.mly"
      ( (Seq _2, _4, prefetch_and_create_state _6) )
# 673 "src/plugins/aorai/yaparser.ml"
               : 'transition))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'actions) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 248 "src/plugins/aorai/yaparser.mly"
      ( (Otherwise, _2, prefetch_and_create_state _4) )
# 681 "src/plugins/aorai/yaparser.ml"
               : 'transition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'actions) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 250 "src/plugins/aorai/yaparser.mly"
      ( (Seq (to_seq PTrue), _1, prefetch_and_create_state _3) )
# 689 "src/plugins/aorai/yaparser.ml"
               : 'transition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'seq_elt) in
    Obj.repr(
# 254 "src/plugins/aorai/yaparser.mly"
            ( _1 )
# 696 "src/plugins/aorai/yaparser.ml"
               : 'non_empty_seq))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'seq_elt) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'seq) in
    Obj.repr(
# 255 "src/plugins/aorai/yaparser.mly"
                           ( _1 @ _3 )
# 704 "src/plugins/aorai/yaparser.ml"
               : 'non_empty_seq))
; (fun __caml_parser_env ->
    Obj.repr(
# 259 "src/plugins/aorai/yaparser.mly"
                  ( [] )
# 710 "src/plugins/aorai/yaparser.ml"
               : 'seq))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'non_empty_seq) in
    Obj.repr(
# 260 "src/plugins/aorai/yaparser.mly"
                  ( _1 )
# 717 "src/plugins/aorai/yaparser.ml"
               : 'seq))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'single_cond) in
    Obj.repr(
# 264 "src/plugins/aorai/yaparser.mly"
                ( to_seq _1 )
# 724 "src/plugins/aorai/yaparser.ml"
               : 'guard))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'non_empty_seq) in
    Obj.repr(
# 265 "src/plugins/aorai/yaparser.mly"
                                  ( _2 )
# 731 "src/plugins/aorai/yaparser.ml"
               : 'guard))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'pre_cond) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'seq) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'post_cond) in
    Obj.repr(
# 267 "src/plugins/aorai/yaparser.mly"
      ( let pre_cond =
          match _2 with
            | Behavior b -> PCall(_1,Some b)
            | Pre c -> PAnd (PCall(_1,None), c)
        in
        let post_cond =
          match _6 with
            | None -> PReturn _1
            | Some c -> PAnd (PReturn _1,c)
        in
        (to_seq pre_cond) @ _4 @ to_seq post_cond
      )
# 752 "src/plugins/aorai/yaparser.ml"
               : 'guard))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'non_empty_seq) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'post_cond) in
    Obj.repr(
# 280 "src/plugins/aorai/yaparser.mly"
      ( let post_cond =
          match _5 with
            | None -> PReturn _1
            | Some c -> PAnd (PReturn _1,c)
        in
        (to_seq (PCall (_1, None))) @ _3 @ to_seq post_cond
      )
# 767 "src/plugins/aorai/yaparser.ml"
               : 'guard))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'post_cond) in
    Obj.repr(
# 288 "src/plugins/aorai/yaparser.mly"
      ( let post_cond =
          match _4 with
            | None -> PReturn _1
            | Some c -> PAnd (PReturn _1,c)
        in
        (to_seq (PCall (_1, None))) @ to_seq post_cond
      )
# 781 "src/plugins/aorai/yaparser.ml"
               : 'guard))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 298 "src/plugins/aorai/yaparser.mly"
                            ( Behavior _2 )
# 788 "src/plugins/aorai/yaparser.ml"
               : 'pre_cond))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'single_cond) in
    Obj.repr(
# 299 "src/plugins/aorai/yaparser.mly"
                                          ( Pre _2 )
# 795 "src/plugins/aorai/yaparser.ml"
               : 'pre_cond))
; (fun __caml_parser_env ->
    Obj.repr(
# 303 "src/plugins/aorai/yaparser.mly"
                  ( None )
# 801 "src/plugins/aorai/yaparser.ml"
               : 'post_cond))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'single_cond) in
    Obj.repr(
# 304 "src/plugins/aorai/yaparser.mly"
                                          ( Some _2 )
# 808 "src/plugins/aorai/yaparser.ml"
               : 'post_cond))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'guard) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'repetition) in
    Obj.repr(
# 308 "src/plugins/aorai/yaparser.mly"
                     (
    let min, max = _2 in
    match _1 with
      | [ s ] when Data_for_aorai.is_single s ->
        [ { s with min_rep = min; max_rep = max } ]
      | l ->
        if is_no_repet (min,max) then
          l (* [ a; [b;c]; d] is equivalent to [a;b;c;d] *)
        else [ { condition = None; nested = l; min_rep = min; max_rep = max } ]
  )
# 825 "src/plugins/aorai/yaparser.ml"
               : 'seq_elt))
; (fun __caml_parser_env ->
    Obj.repr(
# 322 "src/plugins/aorai/yaparser.mly"
      ( Some Data_for_aorai.cst_one, Some Data_for_aorai.cst_one )
# 831 "src/plugins/aorai/yaparser.ml"
               : 'repetition))
; (fun __caml_parser_env ->
    Obj.repr(
# 323 "src/plugins/aorai/yaparser.mly"
         ( Some Data_for_aorai.cst_one, None)
# 837 "src/plugins/aorai/yaparser.ml"
               : 'repetition))
; (fun __caml_parser_env ->
    Obj.repr(
# 324 "src/plugins/aorai/yaparser.mly"
         ( None, None )
# 843 "src/plugins/aorai/yaparser.ml"
               : 'repetition))
; (fun __caml_parser_env ->
    Obj.repr(
# 325 "src/plugins/aorai/yaparser.mly"
             ( None, Some Data_for_aorai.cst_one )
# 849 "src/plugins/aorai/yaparser.ml"
               : 'repetition))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'arith_relation) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'arith_relation) in
    Obj.repr(
# 326 "src/plugins/aorai/yaparser.mly"
                                                      ( Some _2, Some _4 )
# 857 "src/plugins/aorai/yaparser.ml"
               : 'repetition))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'arith_relation) in
    Obj.repr(
# 327 "src/plugins/aorai/yaparser.mly"
                                 ( Some _2, Some _2 )
# 864 "src/plugins/aorai/yaparser.ml"
               : 'repetition))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'arith_relation) in
    Obj.repr(
# 328 "src/plugins/aorai/yaparser.mly"
                                       ( Some _2, None )
# 871 "src/plugins/aorai/yaparser.ml"
               : 'repetition))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'arith_relation) in
    Obj.repr(
# 329 "src/plugins/aorai/yaparser.mly"
                                       ( None, Some _3 )
# 878 "src/plugins/aorai/yaparser.ml"
               : 'repetition))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 333 "src/plugins/aorai/yaparser.mly"
      ( POr (PCall (_3,None), PReturn _3) )
# 885 "src/plugins/aorai/yaparser.ml"
               : 'single_cond))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 334 "src/plugins/aorai/yaparser.mly"
                                      ( PCall (_3,None) )
# 892 "src/plugins/aorai/yaparser.ml"
               : 'single_cond))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 335 "src/plugins/aorai/yaparser.mly"
                                        ( PReturn _3 )
# 899 "src/plugins/aorai/yaparser.ml"
               : 'single_cond))
; (fun __caml_parser_env ->
    Obj.repr(
# 336 "src/plugins/aorai/yaparser.mly"
         ( PTrue )
# 905 "src/plugins/aorai/yaparser.ml"
               : 'single_cond))
; (fun __caml_parser_env ->
    Obj.repr(
# 337 "src/plugins/aorai/yaparser.mly"
          ( PFalse )
# 911 "src/plugins/aorai/yaparser.ml"
               : 'single_cond))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'single_cond) in
    Obj.repr(
# 338 "src/plugins/aorai/yaparser.mly"
                    ( PNot _2 )
# 918 "src/plugins/aorai/yaparser.ml"
               : 'single_cond))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'single_cond) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'single_cond) in
    Obj.repr(
# 339 "src/plugins/aorai/yaparser.mly"
                                ( PAnd (_1,_3) )
# 926 "src/plugins/aorai/yaparser.ml"
               : 'single_cond))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'single_cond) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'single_cond) in
    Obj.repr(
# 340 "src/plugins/aorai/yaparser.mly"
                               ( POr (_1,_3) )
# 934 "src/plugins/aorai/yaparser.ml"
               : 'single_cond))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'single_cond) in
    Obj.repr(
# 341 "src/plugins/aorai/yaparser.mly"
                              ( _2 )
# 941 "src/plugins/aorai/yaparser.ml"
               : 'single_cond))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logic_relation) in
    Obj.repr(
# 342 "src/plugins/aorai/yaparser.mly"
                   ( _1 )
# 948 "src/plugins/aorai/yaparser.ml"
               : 'single_cond))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'arith_relation) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'arith_relation) in
    Obj.repr(
# 346 "src/plugins/aorai/yaparser.mly"
                                     ( PRel(Eq, _1, _3) )
# 956 "src/plugins/aorai/yaparser.ml"
               : 'logic_relation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'arith_relation) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'arith_relation) in
    Obj.repr(
# 347 "src/plugins/aorai/yaparser.mly"
                                     ( PRel(Lt, _1, _3) )
# 964 "src/plugins/aorai/yaparser.ml"
               : 'logic_relation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'arith_relation) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'arith_relation) in
    Obj.repr(
# 348 "src/plugins/aorai/yaparser.mly"
                                     ( PRel(Gt, _1, _3) )
# 972 "src/plugins/aorai/yaparser.ml"
               : 'logic_relation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'arith_relation) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'arith_relation) in
    Obj.repr(
# 349 "src/plugins/aorai/yaparser.mly"
                                     ( PRel(Le, _1, _3) )
# 980 "src/plugins/aorai/yaparser.ml"
               : 'logic_relation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'arith_relation) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'arith_relation) in
    Obj.repr(
# 350 "src/plugins/aorai/yaparser.mly"
                                     ( PRel(Ge, _1, _3) )
# 988 "src/plugins/aorai/yaparser.ml"
               : 'logic_relation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'arith_relation) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'arith_relation) in
    Obj.repr(
# 351 "src/plugins/aorai/yaparser.mly"
                                      ( PRel(Neq, _1, _3) )
# 996 "src/plugins/aorai/yaparser.ml"
               : 'logic_relation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'arith_relation) in
    Obj.repr(
# 352 "src/plugins/aorai/yaparser.mly"
                              ( PRel (Neq, _1, PCst(IntConstant "0")) )
# 1003 "src/plugins/aorai/yaparser.ml"
               : 'logic_relation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'arith_relation_mul) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'arith_relation) in
    Obj.repr(
# 356 "src/plugins/aorai/yaparser.mly"
                                           ( PBinop(Badd,_1,_3) )
# 1011 "src/plugins/aorai/yaparser.ml"
               : 'arith_relation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'arith_relation_mul) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'arith_relation) in
    Obj.repr(
# 357 "src/plugins/aorai/yaparser.mly"
                                            ( PBinop(Bsub,_1,_3) )
# 1019 "src/plugins/aorai/yaparser.ml"
               : 'arith_relation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'arith_relation_mul) in
    Obj.repr(
# 358 "src/plugins/aorai/yaparser.mly"
                                     ( _1 )
# 1026 "src/plugins/aorai/yaparser.ml"
               : 'arith_relation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'arith_relation_mul) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'access_or_const) in
    Obj.repr(
# 362 "src/plugins/aorai/yaparser.mly"
                                             ( PBinop(Bdiv,_1,_3) )
# 1034 "src/plugins/aorai/yaparser.ml"
               : 'arith_relation_mul))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'arith_relation_mul) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'access_or_const) in
    Obj.repr(
# 363 "src/plugins/aorai/yaparser.mly"
                                            ( PBinop(Bmul, _1, _3) )
# 1042 "src/plugins/aorai/yaparser.ml"
               : 'arith_relation_mul))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'arith_relation_mul) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'access_or_const) in
    Obj.repr(
# 364 "src/plugins/aorai/yaparser.mly"
                                               ( PBinop(Bmod, _1, _3) )
# 1050 "src/plugins/aorai/yaparser.ml"
               : 'arith_relation_mul))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'arith_relation_bw) in
    Obj.repr(
# 365 "src/plugins/aorai/yaparser.mly"
                                    ( _1 )
# 1057 "src/plugins/aorai/yaparser.ml"
               : 'arith_relation_mul))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'access_or_const) in
    Obj.repr(
# 369 "src/plugins/aorai/yaparser.mly"
                                  ( _1 )
# 1064 "src/plugins/aorai/yaparser.ml"
               : 'arith_relation_bw))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'arith_relation_bw) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'access_or_const) in
    Obj.repr(
# 370 "src/plugins/aorai/yaparser.mly"
                                          ( PBinop(Bbw_and,_1,_3) )
# 1072 "src/plugins/aorai/yaparser.ml"
               : 'arith_relation_bw))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'arith_relation_bw) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'access_or_const) in
    Obj.repr(
# 371 "src/plugins/aorai/yaparser.mly"
                                           ( PBinop(Bbw_or,_1,_3) )
# 1080 "src/plugins/aorai/yaparser.ml"
               : 'arith_relation_bw))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'arith_relation_bw) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'access_or_const) in
    Obj.repr(
# 372 "src/plugins/aorai/yaparser.mly"
                                            ( PBinop(Bbw_xor,_1,_3) )
# 1088 "src/plugins/aorai/yaparser.ml"
               : 'arith_relation_bw))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 376 "src/plugins/aorai/yaparser.mly"
        ( PCst (IntConstant _1) )
# 1095 "src/plugins/aorai/yaparser.ml"
               : 'access_or_const))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 377 "src/plugins/aorai/yaparser.mly"
              ( PUnop (Uminus, PCst (IntConstant _2)) )
# 1102 "src/plugins/aorai/yaparser.ml"
               : 'access_or_const))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'access) in
    Obj.repr(
# 378 "src/plugins/aorai/yaparser.mly"
                      ( _1 )
# 1109 "src/plugins/aorai/yaparser.ml"
               : 'access_or_const))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'arith_relation) in
    Obj.repr(
# 379 "src/plugins/aorai/yaparser.mly"
                                 ( _2 )
# 1116 "src/plugins/aorai/yaparser.ml"
               : 'access_or_const))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'access) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 384 "src/plugins/aorai/yaparser.mly"
                          ( PField(_1,_3) )
# 1124 "src/plugins/aorai/yaparser.ml"
               : 'access))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'access) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'access_or_const) in
    Obj.repr(
# 385 "src/plugins/aorai/yaparser.mly"
                                           ( PArrget(_1,_3) )
# 1132 "src/plugins/aorai/yaparser.ml"
               : 'access))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'access_leaf) in
    Obj.repr(
# 386 "src/plugins/aorai/yaparser.mly"
                    (_1)
# 1139 "src/plugins/aorai/yaparser.ml"
               : 'access))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'access) in
    Obj.repr(
# 390 "src/plugins/aorai/yaparser.mly"
                ( PUnop (Ustar,_2) )
# 1146 "src/plugins/aorai/yaparser.ml"
               : 'access_leaf))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 391 "src/plugins/aorai/yaparser.mly"
                                            ( PPrm(_1,_5) )
# 1154 "src/plugins/aorai/yaparser.ml"
               : 'access_leaf))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 392 "src/plugins/aorai/yaparser.mly"
               ( PVar _1 )
# 1161 "src/plugins/aorai/yaparser.ml"
               : 'access_leaf))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'access) in
    Obj.repr(
# 393 "src/plugins/aorai/yaparser.mly"
                         ( _2 )
# 1168 "src/plugins/aorai/yaparser.ml"
               : 'access_leaf))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 394 "src/plugins/aorai/yaparser.mly"
            ( PMetavar _1 )
# 1175 "src/plugins/aorai/yaparser.ml"
               : 'access_leaf))
; (fun __caml_parser_env ->
    Obj.repr(
# 398 "src/plugins/aorai/yaparser.mly"
                                    ( [] )
# 1181 "src/plugins/aorai/yaparser.ml"
               : 'actions))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'non_empty_actions) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'opt_semicolon) in
    Obj.repr(
# 399 "src/plugins/aorai/yaparser.mly"
                                    ( _1 )
# 1189 "src/plugins/aorai/yaparser.ml"
               : 'actions))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'non_empty_actions) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'action) in
    Obj.repr(
# 403 "src/plugins/aorai/yaparser.mly"
                                        ( _1 @ [_3] )
# 1197 "src/plugins/aorai/yaparser.ml"
               : 'non_empty_actions))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'action) in
    Obj.repr(
# 404 "src/plugins/aorai/yaparser.mly"
                                        ( [_1] )
# 1204 "src/plugins/aorai/yaparser.ml"
               : 'non_empty_actions))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'arith_relation) in
    Obj.repr(
# 408 "src/plugins/aorai/yaparser.mly"
                               ( Metavar_assign (_1, _3) )
# 1212 "src/plugins/aorai/yaparser.ml"
               : 'action))
; (fun __caml_parser_env ->
    Obj.repr(
# 412 "src/plugins/aorai/yaparser.mly"
                ()
# 1218 "src/plugins/aorai/yaparser.ml"
               : 'opt_semicolon))
; (fun __caml_parser_env ->
    Obj.repr(
# 413 "src/plugins/aorai/yaparser.mly"
                ()
# 1224 "src/plugins/aorai/yaparser.ml"
               : 'opt_semicolon))
(* Entry main *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
|]
let yytables =
  { Parsing.actions=yyact;
    Parsing.transl_const=yytransl_const;
    Parsing.transl_block=yytransl_block;
    Parsing.lhs=yylhs;
    Parsing.len=yylen;
    Parsing.defred=yydefred;
    Parsing.dgoto=yydgoto;
    Parsing.sindex=yysindex;
    Parsing.rindex=yyrindex;
    Parsing.gindex=yygindex;
    Parsing.tablesize=yytablesize;
    Parsing.table=yytable;
    Parsing.check=yycheck;
    Parsing.error_function=parse_error;
    Parsing.names_const=yynames_const;
    Parsing.names_block=yynames_block }
let main (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 1 lexfun lexbuf : Promelaast.parsed_automaton)
